Method: Pio::Echo::Reply#initialize
- Defined in:
- lib/pio/echo/reply.rb
#initialize ⇒ Reply #initialize(transaction_id) ⇒ Reply #initialize(user_options) ⇒ Reply
Creates an EchoReply OpenFlow message. This message can be used to measure the bandwidth of a controller/switch connection as well as to verify its liveness.
40 41 42 |
# File 'lib/pio/echo/reply.rb', line 40 def initialize( = {}) super REPLY, end |